Skip to contents

[Deprecated] This is an accessor function for retrieving the numeric value of the effective median dose from a skrmdb object object generated by ReedMuench, SpearKarb, or DragBehr.

Usage

getED(x)

Arguments

x

class skrmdb.

Value

the estimated ED50.