Skip to contents

This is an accessor function for retrieving the numeric value of the variance from a skrmdb object object generated by ReedMuench, SpearKarb, or DragBehr.

Usage

getvar(x)

Arguments

x

class skrmdb.

Value

the estimated variance.

Examples

temp <- DragBehr(y = c(0, 3, 5, 8, 10, 10), n = rep(10, 6), x = 1:6)
#> Warning: skrmdb :: Calling this function with the parameters y, n, x is depreciated.
getvar(temp)
#> [1] NA