This is an accessor function for retrieving the data used to compute the
effective median dose from a skrmdb object object generated by
ReedMuench, SpearKarb, or DragBehr.
Arguments
- x
class skrmdb.
Value
a dataframe containing the sorted data.
Examples
temp <- DragBehr(y = c(0, 3, 5, 8, 10, 10), n = rep(10, 6), x = 1:6)
#> Warning: skrmdb :: Calling this function with the parameters y, n, x is depreciated.
getdata(temp)
#> x y n y_inc y_dec
#> 1 1 0 10 0 10
#> 2 2 3 10 3 7
#> 3 3 5 10 5 5
#> 4 4 8 10 8 2
#> 5 5 10 10 10 0
#> 6 6 10 10 10 0