Accessor to retrieve the variance from a skrmdb object
getvar.RdThis is an accessor function for retrieving the numeric value of the variance
from a skrmdb object object generated by ReedMuench, SpearKarb,
or DragBehr.

getvar.RdThis is an accessor function for retrieving the numeric value of the variance
from a skrmdb object object generated by ReedMuench, SpearKarb,
or DragBehr.